==> dislog-2.2.0.tar.gz: dislog-2.2.0/tests/test_sync.py <==
"""
    DiscordWebhookLogger (dislog) provides an interface for using a Discord webhook as a logger.
    Copyright (C) 2023 Parker Wahle

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
from __future__ import annotations

import sys
from time import sleep

from . import *


def test_sync_handler(webhook_url: str, python_version_ident: str) -> None:
    """
    Tests the handler running in synchronous mode (non-asyncio).
    """
    logger = get_logger(webhook_url, run_async=False)

    logger.exception(f"Sync Exception on {python_version_ident}!")
    logger.critical(f"Sync Critical on {python_version_ident}!")
    logger.error(f"Sync Error on {python_version_ident}!")
    logger.warning(f"Sync Warning on {python_version_ident}!")
    logger.info(f"Sync Info on {python_version_ident}!")
    logger.debug(f"Sync Debug on {python_version_ident}!")
    # Output must be manually validated.

    for handler in logger.handlers.copy():
        logger.removeHandler(handler)
        handler.close()


__all__ = ("test_sync_handler",)

==> dislog-3.0.0.tar.gz: dislog-3.0.0/tests/test_sync.py <==
"""
    DiscordWebhookLogger (dislog) provides an interface for using a Discord webhook as a logger.
    Copyright (C) 2023 Parker Wahle

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
from __future__ import annotations

from . import *


def test_sync_handler(webhook_url: str, python_version_ident: str) -> None:
    """
    Tests the handler running in synchronous mode (non-asyncio).
    """
    logger = get_logger(webhook_url)

    logger.exception(f"Sync Exception on {python_version_ident}!")
    logger.critical(f"Sync Critical on {python_version_ident}!")
    logger.error(f"Sync Error on {python_version_ident}!")
    logger.warning(f"Sync Warning on {python_version_ident}!")
    logger.info(f"Sync Info on {python_version_ident}!")
    logger.debug(f"Sync Debug on {python_version_ident}!")
    # Output must be manually validated.

    for handler in logger.handlers.copy():
        logger.removeHandler(handler)
        handler.close()


__all__ = ("test_sync_handler",)
